%define       anolis_release 3
%global       dir_name     IPMITOOL
%global       dir_version  1_8_18

Name:         ipmitool
Summary:      Utility for IPMI control
Version:      1.8.18
Release:      %{anolis_release}%{?dist}
License:      BSD
URL:          https://github.com/ipmitool/ipmitool
Source0:      %{url}/archive/refs/tags//%{name}-%{version}.tar.gz
Source1:      openipmi-ipmievd.sysconf
Source2:      ipmievd.service
Source3:      exchange-bmc-os-info.service
Source4:      exchange-bmc-os-info.sysconf
Source5:      set-bmc-url.sh
Source6:      exchange-bmc-os-info

Patch1:       0001-CVE-2011-4339-OpenIPMI.patch
Patch2:       0002-openssl.patch
Patch3:       0003-ipmitool-1.8.11-set-kg-key.patch
Patch4:       0004-slowswid.patch
Patch5:       0005-sensor-id-length.patch
Patch6:       0006-enable-usb.patch
Patch7:       0007-check-input.patch
Patch8:       0008-add-extern.patch
Patch9:       0009-best-cipher.patch
Patch10:      0010-pef-missing-newline.patch
Patch11:      0011-expand-sensor-name-column.patch
Patch12:      0012-CVE-2020-5208.patch
Patch13:      0013-fru-Fix-crashes-on-6-bit-ASCII-strings.patch

BuildRequires: libtool
BuildRequires: ncurses-devel
BuildRequires: openssl-devel
BuildRequires: readline-devel
BuildRequires: automake autoconf
%{?systemd_requires}
BuildRequires: systemd
# bootstrap
Obsoletes: OpenIPMI-tools < 2.0.14-3
Provides: OpenIPMI-tools = 2.0.14-3


%description
IPMITool is a command line utility that allows users to interface with IPMI-enabled
systems. IPMI (Intelligent Platform Management Interface) is a standardized interface
for managing and monitoring servers and other computing systems. With IPMITool, system
administrators can remotely monitor server health, manage firmware updates, and
configure system settings.

IPMITool supports various IPMI implementations, including those from major vendors such
as Dell, HP, and IBM. It can be used to retrieve sensor data (such as temperature,
voltage, and fan speed), reset or power off/on a system, and view event logs. IPMITool
can also be used to manage firmware updates, configure the BMC (Baseboard Management
Controller), and perform other administrative tasks related to IPMI-enabled systems.

One of the key benefits of IPMITool is its flexibility. It supports a wide range of
options and commands, allowing administrators to customize their monitoring and
management workflows. IPMITool can be used on Linux, Windows, and other operating
systems, and it can also be integrated with other monitoring and management tools.

Overall, IPMITool is a powerful and versatile tool for managing and monitoring IPMI-
enabled systems. It provides system administrators with granular control over their
systems and enables them to quickly diagnose and resolve issues.

%package -n ipmievd
Summary: IPMI event daemon for sending events to syslog
Requires: ipmitool
%{?systemd_requires}
BuildRequires: systemd

%description -n ipmievd
ipmievd is a daemon which will listen for events from the BMC that are
being  sent to the SEL and also log those messages to syslog.


%package -n bmc-snmp-proxy
Summary: Reconfigure SNMP to include host SNMP agent within BMC
Requires: net-snmp
Requires: exchange-bmc-os-info
BuildArch: noarch

%description -n bmc-snmp-proxy
IPMITool BMC-SNMP-Proxy is a feature in IPMITool that allows SNMP-based
monitoring tools to access IPMI sensor data through a proxy. This feature
provides a way to integrate IPMI-enabled hardware into SNMP-based management
systems, such as Nagios or Icinga.

The BMC-SNMP-Proxy works by translating SNMP requests into IPMI requests,
which are then sent to the target system's Baseboard Management Controller
(BMC). The BMC responds with the requested sensor data, which is then
translated back into SNMP format and returned to the monitoring tool.

This feature is useful for organizations that want to use SNMP-based
monitoring tools to manage their IPMI-enabled hardware. SNMP is a widely-used
protocol for network management, and many organizations already have existing
SNMP monitoring systems in place. By using the BMC-SNMP-Proxy, organizations
can leverage their existing monitoring infrastructure to monitor their
IPMI-enabled hardware.

It is important to note that the BMC-SNMP-Proxy requires that the target
system's BMC is configured with SNMP support. Additionally, the proxy must be
configured with the appropriate credentials to access the target system's
BMC.

Overall, IPMITool BMC-SNMP-Proxy is a powerful feature that enables
organizations to integrate IPMI-enabled hardware into their existing network
management infrastructure. It provides a simple and efficient way to monitor
hardware health and quickly detect and resolve issues.

%package -n exchange-bmc-os-info
Summary: Let OS and BMC exchange info
Requires: hostname
Requires: ipmitool
%{?systemd_requires}
BuildRequires: systemd
BuildRequires: make
BuildArch: noarch

%description -n exchange-bmc-os-info
IPMITool exchange-bmc-os-info is a feature that allows the Baseboard Management
Controller (BMC) to exchange information with the operating system running on
the host system. This feature can be used to facilitate health monitoring and
management of the host system.

When the exchange-bmc-os-info command is executed, the BMC requests information
about the operating system running on the host system. The operating system
responds with information about its status, including its health, power status,
and other relevant information.

The BMC can use this information to detect and respond to issues with the host
system. For example, if the operating system reports that it is experiencing
high CPU usage, the BMC can adjust fan speeds to increase cooling and prevent
overheating. Similarly, if the operating system reports that it is running low
on disk space, the BMC can send alerts to administrators so that they can take
action to resolve the issue.

Overall, the exchange-bmc-os-info feature provides a powerful mechanism for
monitoring and managing the health of the host system. When used in conjunction
with other IPMI features, such as sensor data recording and event logging, it
can help ensure that the host system remains available and responsive to user
needs.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -n %{name}-%{dir_name}_%{dir_version} -p1

for f in AUTHORS ChangeLog; do
    iconv -f iso-8859-1 -t utf8 < ${f} > ${f}.utf8
    mv ${f}.utf8 ${f}
done

%build
aclocal
libtoolize --automake --copy
autoheader
automake --foreign --add-missing --copy
aclocal
autoconf
automake --foreign

%configure --disable-dependency-tracking --enable-file-security --disable-intf-free
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

install -D -p -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/ipmievd.service
install -D -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/ipmievd
install -D -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/exchange-bmc-os-info.service
install -D -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/exchange-bmc-os-info
install -D -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/profile.d/set-bmc-url.sh
install -D -m 755 %{SOURCE6} %{buildroot}%{_libexecdir}/exchange-bmc-os-info


install -D -m 644 contrib/bmc-snmp-proxy.sysconf %{buildroot}%{_sysconfdir}/sysconfig/bmc-snmp-proxy
install -D -m 644 contrib/bmc-snmp-proxy.service %{buildroot}%{_unitdir}/bmc-snmp-proxy.service
install -D -m 755 contrib/bmc-snmp-proxy         %{buildroot}%{_libexecdir}/bmc-snmp-proxy

rm -rf %{buildroot}/%{_datadir}/doc/ipmitool 

%generate_compatibility_deps

%post -n ipmievd
%systemd_post ipmievd.service

%preun -n ipmievd
%systemd_preun ipmievd.service

%postun -n ipmievd
%systemd_postun_with_restart ipmievd.service

%post -n exchange-bmc-os-info
%systemd_post exchange-bmc-os-info.service

%preun -n exchange-bmc-os-info
%systemd_preun exchange-bmc-os-info.service

%postun -n exchange-bmc-os-info
%systemd_postun_with_restart exchange-bmc-os-info.service


%triggerun -- ipmievd < 1.8.11-7
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply ipmievd
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save ipmievd >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del ipmievd >/dev/null 2>&1 || :
/bin/systemctl try-restart ipmievd.service >/dev/null 2>&1 || :

%files
%dir %{abidir}
%{_bindir}/ipmitool
%{_datadir}/ipmitool
%{_mandir}/man1/ipmitool.1*
%{abidir}/ipmitool-option.list
%license COPYING

%files -n ipmievd
%config(noreplace) %{_sysconfdir}/sysconfig/ipmievd
%{_sbindir}/ipmievd
%{_mandir}/man8/ipmievd.8*
%{_unitdir}/ipmievd.service
%{abidir}/ipmievd-option.list

%files -n exchange-bmc-os-info
%config(noreplace) %{_sysconfdir}/sysconfig/exchange-bmc-os-info
%{_libexecdir}/exchange-bmc-os-info
%{_sysconfdir}/profile.d/set-bmc-url.sh
%{_unitdir}/exchange-bmc-os-info.service

%files -n bmc-snmp-proxy
%config(noreplace) %{_sysconfdir}/sysconfig/bmc-snmp-proxy
%{_libexecdir}/bmc-snmp-proxy
%{_unitdir}/bmc-snmp-proxy.service

%files doc
%doc AUTHORS ChangeLog README

%changelog
* Thu Apr 13 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.8.18-3
- Update some description

* Fri Dec 02 2022 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.8.18-2
- Add a patch and doc package

* Fri Apr 15 2022 yuanhui <yuanhui@linux.alibaba.com> - 1.8.18-1
- Init ipmitool for anolis os 23
